/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __BUTTON_BAR_H__
#define __BUTTON_BAR_H__

#include <config.h>
#include <gnome.h>
#include "config_common.h"

#define TOOLBAR_TYPE_TEXT_ICONS 0
#define TOOLBAR_TYPE_TEXT_ONLY 1
#define TOOLBAR_TYPE_ICONS_ONLY 2

void enable_gnome_button_bar (GtkWidget * window, gint type);
void update_toolbar_style ();
void buttons_set_sensitive (gboolean sensitive);
void buttons_set_all_sensitive (gboolean sensitive);
void cb_new_file (GtkWidget * w, gpointer data);
void cb_open_recent (GtkWidget * w, gpointer data);
void cb_open_cat (GtkWidget * w, gpointer data);
void cb_merge_cat (GtkWidget * w, gpointer data);
void cb_fast_save (GtkWidget * w, gpointer data);
void cb_save_cat (GtkWidget * w, gpointer data);
void cb_quit_prog (GtkWidget * w, gpointer data);
void cb_edit_categories (GtkWidget * w, gpointer data);
void cb_run_setup (GtkWidget * w, gpointer data);
void cb_create_search_dialog (GtkWidget * w, gpointer data);
void cb_open_report_dialog (GtkWidget * w, gpointer data);
void cb_fast_add_disk (GtkWidget * w, gpointer data);
void cb_show_select_dir_win (GtkWidget * w, gpointer data);
void cb_cat_info (GtkWidget * w, gpointer data);
void cb_about_gtktalog (GtkWidget * w, gpointer data);


#endif
